package com.bipt.intelligentapplicationorchestrationservice.service.Impl;

import com.bipt.intelligentapplicationorchestrationservice.mapper.ModelMapper;
import com.bipt.intelligentapplicationorchestrationservice.pojo.ModelDTO;
import com.bipt.intelligentapplicationorchestrationservice.pojo.ModelInfo;
import com.bipt.intelligentapplicationorchestrationservice.pojo.ModelVersion;
import com.bipt.intelligentapplicationorchestrationservice.service.ModelService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

@Slf4j
@Service
public class ModelServiceImpl implements ModelService {
    @Autowired
    private ModelMapper modelMapper;
    /**
     * 创建模型
     * @param dto
     */
    @Transactional  //事务注解
    @Override
    public void createModel(ModelDTO dto) {
        log.info("创建模型");
        //1.插入模型基本信息
        ModelInfo modelInfo = new ModelInfo();
        BeanUtils.copyProperties(dto, modelInfo, "id");
        modelMapper.insertModelInfo(modelInfo);
        log.info("模型id: {}",  modelInfo.getId());
        //2.插入模型版本信息
        ModelVersion modelVersion = new ModelVersion();
        //使用工具类将dto属性复制给modelVersion
        BeanUtils.copyProperties(dto, modelVersion, "id");
        modelVersion.setModelId(modelInfo.getId());
        modelVersion.setCreateTime(LocalDateTime.now());
        modelVersion.setUpdateTime(LocalDateTime.now());
        modelMapper.insertModelVersion(modelVersion);
    }

    /**
     * 新增模型版本
     * @param dto
     */
    @Override
    public void createModelVersion(ModelDTO dto) {
        log.info("新增模型版本");
        ModelVersion modelVersion = new ModelVersion();
        BeanUtils.copyProperties(dto, modelVersion, "id");
        modelVersion.setModelId(dto.getId());
        modelVersion.setCreateTime(LocalDateTime.now());
        modelVersion.setUpdateTime(LocalDateTime.now());
        modelMapper.insertModelVersion(modelVersion);
    }
}
